"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
    from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
    from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
    from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
    globals()['AdditionalMountPoint'] = AdditionalMountPoint
    globals()['OracleRacCustomEnvFile'] = OracleRacCustomEnvFile
    globals()['OracleRacCustomEnvVar'] = OracleRacCustomEnvVar
    globals()['VirtualDatasetHooks'] = VirtualDatasetHooks


class UpdateVDBParameters(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('name',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('db_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('db_password',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('environment_user_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('template_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('pre_script',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('post_script',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('parent_tde_keystore_path',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('parent_tde_keystore_password',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('tde_key_identifier',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('target_vcdb_tde_keystore_path',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('cdb_tde_keystore_password',): {
            'max_length': 1024,
            'min_length': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'name': (str,),  # noqa: E501
            'db_username': (str,),  # noqa: E501
            'db_password': (str,),  # noqa: E501
            'validate_db_credentials': (bool,),  # noqa: E501
            'auto_restart': (bool,),  # noqa: E501
            'environment_user_id': (str,),  # noqa: E501
            'template_id': (str,),  # noqa: E501
            'listener_ids': ([str],),  # noqa: E501
            'new_dbid': (bool,),  # noqa: E501
            'cdc_on_provision': (bool,),  # noqa: E501
            'pre_script': (str,),  # noqa: E501
            'post_script': (str,),  # noqa: E501
            'hooks': (VirtualDatasetHooks,),  # noqa: E501
            'custom_env_vars': ({str: (str,)},),  # noqa: E501
            'custom_env_files': ([str],),  # noqa: E501
            'oracle_rac_custom_env_files': ([OracleRacCustomEnvFile],),  # noqa: E501
            'oracle_rac_custom_env_vars': ([OracleRacCustomEnvVar],),  # noqa: E501
            'parent_tde_keystore_path': (str,),  # noqa: E501
            'parent_tde_keystore_password': (str,),  # noqa: E501
            'tde_key_identifier': (str,),  # noqa: E501
            'target_vcdb_tde_keystore_path': (str,),  # noqa: E501
            'cdb_tde_keystore_password': (str,),  # noqa: E501
            'appdata_source_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),  # noqa: E501
            'additional_mount_points': ([AdditionalMountPoint], none_type,),  # noqa: E501
            'appdata_config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'mount_point': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'name': 'name',  # noqa: E501
        'db_username': 'db_username',  # noqa: E501
        'db_password': 'db_password',  # noqa: E501
        'validate_db_credentials': 'validate_db_credentials',  # noqa: E501
        'auto_restart': 'auto_restart',  # noqa: E501
        'environment_user_id': 'environment_user_id',  # noqa: E501
        'template_id': 'template_id',  # noqa: E501
        'listener_ids': 'listener_ids',  # noqa: E501
        'new_dbid': 'new_dbid',  # noqa: E501
        'cdc_on_provision': 'cdc_on_provision',  # noqa: E501
        'pre_script': 'pre_script',  # noqa: E501
        'post_script': 'post_script',  # noqa: E501
        'hooks': 'hooks',  # noqa: E501
        'custom_env_vars': 'custom_env_vars',  # noqa: E501
        'custom_env_files': 'custom_env_files',  # noqa: E501
        'oracle_rac_custom_env_files': 'oracle_rac_custom_env_files',  # noqa: E501
        'oracle_rac_custom_env_vars': 'oracle_rac_custom_env_vars',  # noqa: E501
        'parent_tde_keystore_path': 'parent_tde_keystore_path',  # noqa: E501
        'parent_tde_keystore_password': 'parent_tde_keystore_password',  # noqa: E501
        'tde_key_identifier': 'tde_key_identifier',  # noqa: E501
        'target_vcdb_tde_keystore_path': 'target_vcdb_tde_keystore_path',  # noqa: E501
        'cdb_tde_keystore_password': 'cdb_tde_keystore_password',  # noqa: E501
        'appdata_source_params': 'appdata_source_params',  # noqa: E501
        'additional_mount_points': 'additional_mount_points',  # noqa: E501
        'appdata_config_params': 'appdata_config_params',  # noqa: E501
        'config_params': 'config_params',  # noqa: E501
        'mount_point': 'mount_point',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """UpdateVDBParameters - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            name (str): The unique name of the VDB within a group.. [optional]  # noqa: E501
            db_username (str): The username of the database user (Oracle, ASE Only).. [optional]  # noqa: E501
            db_password (str): The password of the database user (Oracle, ASE Only).. [optional]  # noqa: E501
            validate_db_credentials (bool): Whether db_username and db_password must be validated, if present, against the VDB. This must be set to false when credentials validation is not possible, for instance if the VDB is known to be disabled.. [optional] if omitted the server will use the default value of True  # noqa: E501
            auto_restart (bool): Whether to enable VDB restart.. [optional]  # noqa: E501
            environment_user_id (str): The environment user ID to use to connect to the target environment.. [optional]  # noqa: E501
            template_id (str): The ID of the target VDB Template (Oracle Only).. [optional]  # noqa: E501
            listener_ids ([str]): The listener IDs for this provision operation (Oracle Only).. [optional]  # noqa: E501
            new_dbid (bool): Whether to enable new DBID for Oracle. [optional]  # noqa: E501
            cdc_on_provision (bool): Whether to enable CDC on provision for MSSql. [optional]  # noqa: E501
            pre_script (str): Pre script for MSSql.. [optional]  # noqa: E501
            post_script (str): Post script for MSSql.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            custom_env_vars ({str: (str,)}): Environment variable to be set when the engine administers a VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            custom_env_files ([str]): Environment files to be sourced when the Engine administers a VDB. This path can be followed by parameters. Paths and parameters are separated by spaces. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            oracle_rac_custom_env_files ([OracleRacCustomEnvFile]): Environment files to be sourced when the Engine administers an Oracle RAC VDB. This path can be followed by parameters. Paths and parameters are separated by spaces. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            oracle_rac_custom_env_vars ([OracleRacCustomEnvVar]): Environment variable to be set when the engine administers an Oracle RAC VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files. (Oracle Multitenant Only). [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            cdb_tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with the CDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (AppData only), can only be updated while the VDB is disabled.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """UpdateVDBParameters - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            name (str): The unique name of the VDB within a group.. [optional]  # noqa: E501
            db_username (str): The username of the database user (Oracle, ASE Only).. [optional]  # noqa: E501
            db_password (str): The password of the database user (Oracle, ASE Only).. [optional]  # noqa: E501
            validate_db_credentials (bool): Whether db_username and db_password must be validated, if present, against the VDB. This must be set to false when credentials validation is not possible, for instance if the VDB is known to be disabled.. [optional] if omitted the server will use the default value of True  # noqa: E501
            auto_restart (bool): Whether to enable VDB restart.. [optional]  # noqa: E501
            environment_user_id (str): The environment user ID to use to connect to the target environment.. [optional]  # noqa: E501
            template_id (str): The ID of the target VDB Template (Oracle Only).. [optional]  # noqa: E501
            listener_ids ([str]): The listener IDs for this provision operation (Oracle Only).. [optional]  # noqa: E501
            new_dbid (bool): Whether to enable new DBID for Oracle. [optional]  # noqa: E501
            cdc_on_provision (bool): Whether to enable CDC on provision for MSSql. [optional]  # noqa: E501
            pre_script (str): Pre script for MSSql.. [optional]  # noqa: E501
            post_script (str): Post script for MSSql.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            custom_env_vars ({str: (str,)}): Environment variable to be set when the engine administers a VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            custom_env_files ([str]): Environment files to be sourced when the Engine administers a VDB. This path can be followed by parameters. Paths and parameters are separated by spaces. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            oracle_rac_custom_env_files ([OracleRacCustomEnvFile]): Environment files to be sourced when the Engine administers an Oracle RAC VDB. This path can be followed by parameters. Paths and parameters are separated by spaces. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            oracle_rac_custom_env_vars ([OracleRacCustomEnvVar]): Environment variable to be set when the engine administers an Oracle RAC VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution. Custom environment variables can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files. (Oracle Multitenant Only). [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            cdb_tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with the CDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (AppData only), can only be updated while the VDB is disabled.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.accounts_api import AccountsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from delphix.api.gateway.api.accounts_api import AccountsApi
from delphix.api.gateway.api.authorization_api import AuthorizationApi
from delphix.api.gateway.api.bookmarks_api import BookmarksApi
from delphix.api.gateway.api.cdbs_api import CDBsApi
from delphix.api.gateway.api.connectivity_api import ConnectivityApi
from delphix.api.gateway.api.connectors_api import ConnectorsApi
from delphix.api.gateway.api.d_sources_api import DSourcesApi
from delphix.api.gateway.api.database_templates_api import DatabaseTemplatesApi
from delphix.api.gateway.api.environments_api import EnvironmentsApi
from delphix.api.gateway.api.executions_api import ExecutionsApi
from delphix.api.gateway.api.feature_flag_api import FeatureFlagApi
from delphix.api.gateway.api.groups_api import GroupsApi
from delphix.api.gateway.api.jobs_api import JobsApi
from delphix.api.gateway.api.login_api import LoginApi
from delphix.api.gateway.api.management_api import ManagementApi
from delphix.api.gateway.api.masking_environments_api import MaskingEnvironmentsApi
from delphix.api.gateway.api.masking_jobs_api import MaskingJobsApi
from delphix.api.gateway.api.password_vaults_api import PasswordVaultsApi
from delphix.api.gateway.api.reporting_api import ReportingApi
from delphix.api.gateway.api.saml_login_api import SamlLoginApi
from delphix.api.gateway.api.snapshots_api import SnapshotsApi
from delphix.api.gateway.api.sources_api import SourcesApi
from delphix.api.gateway.api.test_api import TestApi
from delphix.api.gateway.api.timeflows_api import TimeflowsApi
from delphix.api.gateway.api.vcdbs_api import VCDBsApi
from delphix.api.gateway.api.vdb_groups_api import VDBGroupsApi
from delphix.api.gateway.api.vdbs_api import VDBsApi
from delphix.api.gateway.api.virtualization_policies_api import VirtualizationPoliciesApi



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.copy_masking_job_parameters import CopyMaskingJobParameters
from delphix.api.gateway.model.copy_masking_job_response import CopyMaskingJobResponse
from delphix.api.gateway.model.delete_masking_job_response import DeleteMaskingJobResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.execute_masking_job_parameters import ExecuteMaskingJobParameters
from delphix.api.gateway.model.execute_masking_job_response import ExecuteMaskingJobResponse
from delphix.api.gateway.model.list_masking_job_source_engines_response import ListMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.list_masking_jobs_response import ListMaskingJobsResponse
from delphix.api.gateway.model.masking_job import MaskingJob
from delphix.api.gateway.model.masking_job_connectors_response import MaskingJobConnectorsResponse
from delphix.api.gateway.model.migrate_masking_job_parameters import MigrateMaskingJobParameters
from delphix.api.gateway.model.migrate_masking_job_response import MigrateMaskingJobResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_masking_job_source_engines_response import SearchMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.search_masking_jobs_response import SearchMaskingJobsResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_masking_job_parameters import UpdateMaskingJobParameters


class MaskingJobsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __copy_masking_job(
            self,
            masking_job_id,
            **kwargs
        ):
            """Copies the masking job to another engine.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.copy_masking_job(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                copy_masking_job_parameters (CopyMaskingJobParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CopyMaskingJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.copy_masking_job = _Endpoint(
            settings={
                'response_type': (CopyMaskingJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/copy',
                'operation_id': 'copy_masking_job',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'copy_masking_job_parameters',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'copy_masking_job_parameters':
                        (CopyMaskingJobParameters,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'copy_masking_job_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__copy_masking_job
        )

        def __create_masking_job_tag(
            self,
            masking_job_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Masking Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_masking_job_tag(masking_job_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.
                tags_request (TagsRequest): Tags information for Masking Job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_masking_job_tag = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/tags',
                'operation_id': 'create_masking_job_tag',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'tags_request',
                ],
                'required': [
                    'masking_job_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_masking_job_tag
        )

        def __delete_masking_job(
            self,
            masking_job_id,
            **kwargs
        ):
            """Delete a masking job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_masking_job(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                force (bool): If true, ignores any failures to remove a masking job on an engine.. [optional] if omitted the server will use the default value of False
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteMaskingJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.delete_masking_job = _Endpoint(
            settings={
                'response_type': (DeleteMaskingJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}',
                'operation_id': 'delete_masking_job',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'force',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'force':
                        (bool,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                    'force': 'force',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'force': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_masking_job
        )

        def __delete_masking_job_tag(
            self,
            masking_job_id,
            **kwargs
        ):
            """Delete tags for a Masking Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_masking_job_tag(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.delete_masking_job_tag = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/tags/delete',
                'operation_id': 'delete_masking_job_tag',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'delete_tag',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_masking_job_tag
        )

        def __execute_masking_job(
            self,
            masking_job_id,
            **kwargs
        ):
            """Execute a MaskingJob.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.execute_masking_job(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                execute_masking_job_parameters (ExecuteMaskingJobParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ExecuteMaskingJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.execute_masking_job = _Endpoint(
            settings={
                'response_type': (ExecuteMaskingJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/execute',
                'operation_id': 'execute_masking_job',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'execute_masking_job_parameters',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'execute_masking_job_parameters':
                        (ExecuteMaskingJobParameters,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'execute_masking_job_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__execute_masking_job
        )

        def __get_masking_job_by_id(
            self,
            masking_job_id,
            **kwargs
        ):
            """Retrieve a MaskingJob by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_masking_job_by_id(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MaskingJob
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.get_masking_job_by_id = _Endpoint(
            settings={
                'response_type': (MaskingJob,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}',
                'operation_id': 'get_masking_job_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_masking_job_by_id
        )

        def __get_masking_job_connectors(
            self,
            masking_job_id,
            **kwargs
        ):
            """Get connectors for a Masking Job by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_masking_job_connectors(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MaskingJobConnectorsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.get_masking_job_connectors = _Endpoint(
            settings={
                'response_type': (MaskingJobConnectorsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/connectors',
                'operation_id': 'get_masking_job_connectors',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_masking_job_connectors
        )

        def __get_masking_job_source_engines(
            self,
            **kwargs
        ):
            """Retrieve the list of masking jobs along with their source engine.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_masking_job_source_engines(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListMaskingJobSourceEnginesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_masking_job_source_engines = _Endpoint(
            settings={
                'response_type': (ListMaskingJobSourceEnginesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/source-engines',
                'operation_id': 'get_masking_job_source_engines',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "MASKING_JOB_ID": "masking_job_id",
                        "-MASKING_JOB_ID": "-masking_job_id",
                        "SOURCE_ENGINE_ID": "source_engine_id",
                        "-SOURCE_ENGINE_ID": "-source_engine_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_masking_job_source_engines
        )

        def __get_masking_job_tag(
            self,
            masking_job_id,
            **kwargs
        ):
            """Get tags for a Masking Job.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_masking_job_tag(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.get_masking_job_tag = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/tags',
                'operation_id': 'get_masking_job_tag',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_masking_job_tag
        )

        def __get_masking_jobs(
            self,
            **kwargs
        ):
            """Retrieve the list of masking jobs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_masking_jobs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListMaskingJobsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_masking_jobs = _Endpoint(
            settings={
                'response_type': (ListMaskingJobsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs',
                'operation_id': 'get_masking_jobs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "IS_ON_THE_FLY_MASKING": "is_on_the_fly_masking",
                        "-IS_ON_THE_FLY_MASKING": "-is_on_the_fly_masking",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "LAST_COMPLETED_EXECUTION_DATE": "last_completed_execution_date",
                        "-LAST_COMPLETED_EXECUTION_DATE": "-last_completed_execution_date",
                        "LAST_EXECUTION_STATUS": "last_execution_status",
                        "-LAST_EXECUTION_STATUS": "-last_execution_status"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_masking_jobs
        )

        def __migrate_masking_job(
            self,
            masking_job_id,
            **kwargs
        ):
            """Migrates the masking job from its current source engine to another engine.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.migrate_masking_job(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                migrate_masking_job_parameters (MigrateMaskingJobParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MigrateMaskingJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.migrate_masking_job = _Endpoint(
            settings={
                'response_type': (MigrateMaskingJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}/migrate',
                'operation_id': 'migrate_masking_job',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'migrate_masking_job_parameters',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'migrate_masking_job_parameters':
                        (MigrateMaskingJobParameters,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'migrate_masking_job_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__migrate_masking_job
        )

        def __search_masking_job_source_engines(
            self,
            **kwargs
        ):
            """Search the list of masking jobs along with their source engine.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_masking_job_source_engines(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchMaskingJobSourceEnginesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_masking_job_source_engines = _Endpoint(
            settings={
                'response_type': (SearchMaskingJobSourceEnginesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/source-engines/search',
                'operation_id': 'search_masking_job_source_engines',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "MASKING_JOB_ID": "masking_job_id",
                        "-MASKING_JOB_ID": "-masking_job_id",
                        "SOURCE_ENGINE_ID": "source_engine_id",
                        "-SOURCE_ENGINE_ID": "-source_engine_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_masking_job_source_engines
        )

        def __search_masking_jobs(
            self,
            **kwargs
        ):
            """Search masking jobs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_masking_jobs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies a descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchMaskingJobsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_masking_jobs = _Endpoint(
            settings={
                'response_type': (SearchMaskingJobsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/search',
                'operation_id': 'search_masking_jobs',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "IS_ON_THE_FLY_MASKING": "is_on_the_fly_masking",
                        "-IS_ON_THE_FLY_MASKING": "-is_on_the_fly_masking",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "LAST_COMPLETED_EXECUTION_DATE": "last_completed_execution_date",
                        "-LAST_COMPLETED_EXECUTION_DATE": "-last_completed_execution_date",
                        "LAST_EXECUTION_STATUS": "last_execution_status",
                        "-LAST_EXECUTION_STATUS": "-last_execution_status"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_masking_jobs
        )

        def __update_masking_job_by_id(
            self,
            masking_job_id,
            **kwargs
        ):
            """Update values of a MaskingJob.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_masking_job_by_id(masking_job_id, async_req=True)
            >>> result = thread.get()

            Args:
                masking_job_id (str): The ID of the Masking Job.

            Keyword Args:
                update_masking_job_parameters (UpdateMaskingJobParameters): The new data to update a Masking Job.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MaskingJob
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['masking_job_id'] = \
                masking_job_id
            return self.call_with_http_info(**kwargs)

        self.update_masking_job_by_id = _Endpoint(
            settings={
                'response_type': (MaskingJob,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/masking-jobs/{maskingJobId}',
                'operation_id': 'update_masking_job_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'masking_job_id',
                    'update_masking_job_parameters',
                ],
                'required': [
                    'masking_job_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'masking_job_id',
                ]
            },
            root_map={
                'validations': {
                    ('masking_job_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'masking_job_id':
                        (str,),
                    'update_masking_job_parameters':
                        (UpdateMaskingJobParameters,),
                },
                'attribute_map': {
                    'masking_job_id': 'maskingJobId',
                },
                'location_map': {
                    'masking_job_id': 'path',
                    'update_masking_job_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_masking_job_by_id
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.timeflows_api import TimeflowsApi  # noqa: E501


class TestTimeflowsApi(unittest.TestCase):
    """TimeflowsApi unit test stubs"""

    def setUp(self):
        self.api = TimeflowsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_timeflow_tags(self):
        """Test case for create_timeflow_tags

        Create tags for a Timeflow.  # noqa: E501
        """
        pass

    def test_delete_timeflow(self):
        """Test case for delete_timeflow

        Delete a timeflow.  # noqa: E501
        """
        pass

    def test_delete_timeflow_tags(self):
        """Test case for delete_timeflow_tags

        Delete tags for a Timeflow.  # noqa: E501
        """
        pass

    def test_get_timeflow_by_id(self):
        """Test case for get_timeflow_by_id

        Get a Timeflow by ID.  # noqa: E501
        """
        pass

    def test_get_timeflow_snapshot_day_range(self):
        """Test case for get_timeflow_snapshot_day_range

        Returns the count of TimeFlow snapshots of the Timeflow aggregated by day.  # noqa: E501
        """
        pass

    def test_get_timeflow_tags(self):
        """Test case for get_timeflow_tags

        Get tags for a Timeflow.  # noqa: E501
        """
        pass

    def test_get_timeflows(self):
        """Test case for get_timeflows

        Retrieve the list of timeflows.  # noqa: E501
        """
        pass

    def test_search_timeflows(self):
        """Test case for search_timeflows

        Search timeflows.  # noqa: E501
        """
        pass

    def test_update_timeflow(self):
        """Test case for update_timeflow

        Update values of a timeflow.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.vcdbs_api import VCDBsApi  # noqa: E501


class TestVCDBsApi(unittest.TestCase):
    """VCDBsApi unit test stubs"""

    def setUp(self):
        self.api = VCDBsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vcdb_tags(self):
        """Test case for create_vcdb_tags

        Create tags for a vCDB.  # noqa: E501
        """
        pass

    def test_delete_vcdb_tags(self):
        """Test case for delete_vcdb_tags

        Delete tags for a vCDB.  # noqa: E501
        """
        pass

    def test_get_tags_vcdb(self):
        """Test case for get_tags_vcdb

        Get tags for a vCDB.  # noqa: E501
        """
        pass

    def test_get_vcdb_by_id(self):
        """Test case for get_vcdb_by_id

        Get a CDB by ID (Oracle only).  # noqa: E501
        """
        pass

    def test_get_vcdbs(self):
        """Test case for get_vcdbs

        List all vCDBs (Oracle only).  # noqa: E501
        """
        pass

    def test_search_vcdbs(self):
        """Test case for search_vcdbs

        Search for vCDBs (Oracle only).  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
    from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf
    from delphix.api.gateway.model.config_settings_stg import ConfigSettingsStg
    from delphix.api.gateway.model.hook import Hook
    from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
    from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
    from delphix.api.gateway.model.tag import Tag
    from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
    globals()['AdditionalMountPoint'] = AdditionalMountPoint
    globals()['BaseProvisionVDBParametersAllOf'] = BaseProvisionVDBParametersAllOf
    globals()['ConfigSettingsStg'] = ConfigSettingsStg
    globals()['Hook'] = Hook
    globals()['OracleRacCustomEnvFile'] = OracleRacCustomEnvFile
    globals()['OracleRacCustomEnvVar'] = OracleRacCustomEnvVar
    globals()['Tag'] = Tag
    globals()['VirtualDatasetHooks'] = VirtualDatasetHooks


class BaseProvisionVDBParameters(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('recovery_model',): {
            'FULL': "FULL",
            'SIMPLE': "SIMPLE",
            'BULK_LOGGED': "BULK_LOGGED",
        },
    }

    validations = {
        ('pre_refresh',): {
            'max_items': 100,
        },
        ('post_refresh',): {
            'max_items': 100,
        },
        ('pre_self_refresh',): {
            'max_items': 100,
        },
        ('post_self_refresh',): {
            'max_items': 100,
        },
        ('pre_rollback',): {
            'max_items': 100,
        },
        ('post_rollback',): {
            'max_items': 100,
        },
        ('configure_clone',): {
            'max_items': 100,
        },
        ('pre_snapshot',): {
            'max_items': 100,
        },
        ('post_snapshot',): {
            'max_items': 100,
        },
        ('pre_start',): {
            'max_items': 100,
        },
        ('post_start',): {
            'max_items': 100,
        },
        ('pre_stop',): {
            'max_items': 100,
        },
        ('post_stop',): {
            'max_items': 100,
        },
        ('target_group_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('name',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('database_name',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('cdb_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('cluster_node_ids',): {
            'min_items': 1,
        },
        ('os_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('os_password',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('environment_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('environment_user_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('repository_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('template_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('auxiliary_template_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('file_mapping_rules',): {
            'max_length': 131072,
            'min_length': 1,
        },
        ('oracle_instance_name',): {
            'max_length': 15,
            'min_length': 1,
            'regex': {
                'pattern': r'^[a-zA-Z0-9_]+$',  # noqa: E501
            },
        },
        ('unique_name',): {
            'max_length': 30,
            'min_length': 1,
            'regex': {
                'pattern': r'^[a-zA-Z0-9_\$#]+$',  # noqa: E501
            },
        },
        ('vcdb_name',): {
            'max_length': 256,
            'min_length': 1,
            'regex': {
                'pattern': r'^[a-zA-Z0-9_]+$',  # noqa: E501
            },
        },
        ('vcdb_database_name',): {
            'max_length': 8,
            'min_length': 1,
        },
        ('mount_point',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('snapshot_policy_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('retention_policy_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('pre_script',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('post_script',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('online_log_size',): {
            'inclusive_minimum': 4,
        },
        ('online_log_groups',): {
            'inclusive_minimum': 2,
        },
        ('parent_tde_keystore_path',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('parent_tde_keystore_password',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('tde_exported_key_file_secret',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('tde_key_identifier',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('target_vcdb_tde_keystore_path',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('cdb_tde_keystore_password',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('vcdb_tde_key_identifier',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('privileged_os_user',): {
            'max_length': 32,
            'regex': {
                'pattern': r'^$|^[a-zA-Z_][a-zA-Z0-9_\-]+[$]?$',  # noqa: E501
            },
        },
        ('postgres_port',): {
            'inclusive_maximum': 65536,
            'inclusive_minimum': 1,
        },
        ('tags',): {
            'max_items': 1000,
            'min_items': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'pre_refresh': ([Hook],),  # noqa: E501
            'post_refresh': ([Hook],),  # noqa: E501
            'pre_self_refresh': ([Hook],),  # noqa: E501
            'post_self_refresh': ([Hook],),  # noqa: E501
            'pre_rollback': ([Hook],),  # noqa: E501
            'post_rollback': ([Hook],),  # noqa: E501
            'configure_clone': ([Hook],),  # noqa: E501
            'pre_snapshot': ([Hook],),  # noqa: E501
            'post_snapshot': ([Hook],),  # noqa: E501
            'pre_start': ([Hook],),  # noqa: E501
            'post_start': ([Hook],),  # noqa: E501
            'pre_stop': ([Hook],),  # noqa: E501
            'post_stop': ([Hook],),  # noqa: E501
            'target_group_id': (str,),  # noqa: E501
            'name': (str,),  # noqa: E501
            'database_name': (str,),  # noqa: E501
            'cdb_id': (str,),  # noqa: E501
            'cluster_node_ids': ([str],),  # noqa: E501
            'truncate_log_on_checkpoint': (bool,),  # noqa: E501
            'os_username': (str,),  # noqa: E501
            'os_password': (str,),  # noqa: E501
            'environment_id': (str,),  # noqa: E501
            'environment_user_id': (str,),  # noqa: E501
            'repository_id': (str,),  # noqa: E501
            'auto_select_repository': (bool,),  # noqa: E501
            'vdb_restart': (bool,),  # noqa: E501
            'template_id': (str,),  # noqa: E501
            'auxiliary_template_id': (str,),  # noqa: E501
            'file_mapping_rules': (str,),  # noqa: E501
            'oracle_instance_name': (str,),  # noqa: E501
            'unique_name': (str,),  # noqa: E501
            'vcdb_name': (str,),  # noqa: E501
            'vcdb_database_name': (str,),  # noqa: E501
            'mount_point': (str,),  # noqa: E501
            'open_reset_logs': (bool,),  # noqa: E501
            'snapshot_policy_id': (str,),  # noqa: E501
            'retention_policy_id': (str,),  # noqa: E501
            'recovery_model': (str,),  # noqa: E501
            'pre_script': (str,),  # noqa: E501
            'post_script': (str,),  # noqa: E501
            'cdc_on_provision': (bool,),  # noqa: E501
            'online_log_size': (int,),  # noqa: E501
            'online_log_groups': (int,),  # noqa: E501
            'archive_log': (bool,),  # noqa: E501
            'new_dbid': (bool,),  # noqa: E501
            'listener_ids': ([str],),  # noqa: E501
            'custom_env_vars': ({str: (str,)},),  # noqa: E501
            'custom_env_files': ([str],),  # noqa: E501
            'oracle_rac_custom_env_files': ([OracleRacCustomEnvFile],),  # noqa: E501
            'oracle_rac_custom_env_vars': ([OracleRacCustomEnvVar],),  # noqa: E501
            'parent_tde_keystore_path': (str,),  # noqa: E501
            'parent_tde_keystore_password': (str,),  # noqa: E501
            'tde_exported_key_file_secret': (str,),  # noqa: E501
            'tde_key_identifier': (str,),  # noqa: E501
            'target_vcdb_tde_keystore_path': (str,),  # noqa: E501
            'cdb_tde_keystore_password': (str,),  # noqa: E501
            'vcdb_tde_key_identifier': (str,),  # noqa: E501
            'appdata_source_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),  # noqa: E501
            'additional_mount_points': ([AdditionalMountPoint], none_type,),  # noqa: E501
            'appdata_config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'privileged_os_user': (str,),  # noqa: E501
            'postgres_port': (int,),  # noqa: E501
            'config_settings_stg': ([ConfigSettingsStg],),  # noqa: E501
            'tags': ([Tag],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'pre_refresh': 'pre_refresh',  # noqa: E501
        'post_refresh': 'post_refresh',  # noqa: E501
        'pre_self_refresh': 'pre_self_refresh',  # noqa: E501
        'post_self_refresh': 'post_self_refresh',  # noqa: E501
        'pre_rollback': 'pre_rollback',  # noqa: E501
        'post_rollback': 'post_rollback',  # noqa: E501
        'configure_clone': 'configure_clone',  # noqa: E501
        'pre_snapshot': 'pre_snapshot',  # noqa: E501
        'post_snapshot': 'post_snapshot',  # noqa: E501
        'pre_start': 'pre_start',  # noqa: E501
        'post_start': 'post_start',  # noqa: E501
        'pre_stop': 'pre_stop',  # noqa: E501
        'post_stop': 'post_stop',  # noqa: E501
        'target_group_id': 'target_group_id',  # noqa: E501
        'name': 'name',  # noqa: E501
        'database_name': 'database_name',  # noqa: E501
        'cdb_id': 'cdb_id',  # noqa: E501
        'cluster_node_ids': 'cluster_node_ids',  # noqa: E501
        'truncate_log_on_checkpoint': 'truncate_log_on_checkpoint',  # noqa: E501
        'os_username': 'os_username',  # noqa: E501
        'os_password': 'os_password',  # noqa: E501
        'environment_id': 'environment_id',  # noqa: E501
        'environment_user_id': 'environment_user_id',  # noqa: E501
        'repository_id': 'repository_id',  # noqa: E501
        'auto_select_repository': 'auto_select_repository',  # noqa: E501
        'vdb_restart': 'vdb_restart',  # noqa: E501
        'template_id': 'template_id',  # noqa: E501
        'auxiliary_template_id': 'auxiliary_template_id',  # noqa: E501
        'file_mapping_rules': 'file_mapping_rules',  # noqa: E501
        'oracle_instance_name': 'oracle_instance_name',  # noqa: E501
        'unique_name': 'unique_name',  # noqa: E501
        'vcdb_name': 'vcdb_name',  # noqa: E501
        'vcdb_database_name': 'vcdb_database_name',  # noqa: E501
        'mount_point': 'mount_point',  # noqa: E501
        'open_reset_logs': 'open_reset_logs',  # noqa: E501
        'snapshot_policy_id': 'snapshot_policy_id',  # noqa: E501
        'retention_policy_id': 'retention_policy_id',  # noqa: E501
        'recovery_model': 'recovery_model',  # noqa: E501
        'pre_script': 'pre_script',  # noqa: E501
        'post_script': 'post_script',  # noqa: E501
        'cdc_on_provision': 'cdc_on_provision',  # noqa: E501
        'online_log_size': 'online_log_size',  # noqa: E501
        'online_log_groups': 'online_log_groups',  # noqa: E501
        'archive_log': 'archive_log',  # noqa: E501
        'new_dbid': 'new_dbid',  # noqa: E501
        'listener_ids': 'listener_ids',  # noqa: E501
        'custom_env_vars': 'custom_env_vars',  # noqa: E501
        'custom_env_files': 'custom_env_files',  # noqa: E501
        'oracle_rac_custom_env_files': 'oracle_rac_custom_env_files',  # noqa: E501
        'oracle_rac_custom_env_vars': 'oracle_rac_custom_env_vars',  # noqa: E501
        'parent_tde_keystore_path': 'parentTdeKeystorePath',  # noqa: E501
        'parent_tde_keystore_password': 'parent_tde_keystore_password',  # noqa: E501
        'tde_exported_key_file_secret': 'tde_exported_key_file_secret',  # noqa: E501
        'tde_key_identifier': 'tde_key_identifier',  # noqa: E501
        'target_vcdb_tde_keystore_path': 'target_vcdb_tde_keystore_path',  # noqa: E501
        'cdb_tde_keystore_password': 'cdb_tde_keystore_password',  # noqa: E501
        'vcdb_tde_key_identifier': 'vcdb_tde_key_identifier',  # noqa: E501
        'appdata_source_params': 'appdata_source_params',  # noqa: E501
        'additional_mount_points': 'additional_mount_points',  # noqa: E501
        'appdata_config_params': 'appdata_config_params',  # noqa: E501
        'config_params': 'config_params',  # noqa: E501
        'privileged_os_user': 'privileged_os_user',  # noqa: E501
        'postgres_port': 'postgres_port',  # noqa: E501
        'config_settings_stg': 'config_settings_stg',  # noqa: E501
        'tags': 'tags',  # noqa: E501
    }

    read_only_vars = {
    }

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """BaseProvisionVDBParameters - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            pre_refresh ([Hook]): The commands to execute on the target environment before refreshing the VDB.. [optional]  # noqa: E501
            post_refresh ([Hook]): The commands to execute on the target environment after refreshing the VDB.. [optional]  # noqa: E501
            pre_self_refresh ([Hook]): The commands to execute on the target environment before refreshing the VDB with data from itself.. [optional]  # noqa: E501
            post_self_refresh ([Hook]): The commands to execute on the target environment after refreshing the VDB with data from itself.. [optional]  # noqa: E501
            pre_rollback ([Hook]): The commands to execute on the target environment before rewinding the VDB.. [optional]  # noqa: E501
            post_rollback ([Hook]): The commands to execute on the target environment after rewinding the VDB.. [optional]  # noqa: E501
            configure_clone ([Hook]): The commands to execute on the target environment when the VDB is created or refreshed.. [optional]  # noqa: E501
            pre_snapshot ([Hook]): The commands to execute on the target environment before snapshotting a virtual source. These commands can quiesce any data prior to snapshotting.. [optional]  # noqa: E501
            post_snapshot ([Hook]): The commands to execute on the target environment after snapshotting a virtual source.. [optional]  # noqa: E501
            pre_start ([Hook]): The commands to execute on the target environment before starting a virtual source.. [optional]  # noqa: E501
            post_start ([Hook]): The commands to execute on the target environment after starting a virtual source.. [optional]  # noqa: E501
            pre_stop ([Hook]): The commands to execute on the target environment before stopping a virtual source.. [optional]  # noqa: E501
            post_stop ([Hook]): The commands to execute on the target environment after stopping a virtual source.. [optional]  # noqa: E501
            target_group_id (str): The ID of the group into which the VDB will be provisioned. If unset, a group is selected randomly on the Engine.. [optional]  # noqa: E501
            name (str): The unique name of the provisioned VDB within a group. If unset, a name is randomly generated.. [optional]  # noqa: E501
            database_name (str): The name of the database on the target environment. Defaults to the value of the name property.. [optional]  # noqa: E501
            cdb_id (str): The ID of the container database (CDB) to provision an Oracle Multitenant database into. This corresponds to a CDB or VCDB API object. When this is not set, a new vCDB will be provisioned.. [optional]  # noqa: E501
            cluster_node_ids ([str]): The cluster node ids, name or addresses for this provision operation (Oracle RAC Only).. [optional]  # noqa: E501
            truncate_log_on_checkpoint (bool): Whether to truncate log on checkpoint (ASE only).. [optional]  # noqa: E501
            os_username (str): The name of the privileged user to run the provision operation (Oracle Only).. [optional]  # noqa: E501
            os_password (str): The password of the privileged user to run the provision operation (Oracle Only).. [optional]  # noqa: E501
            environment_id (str): The ID of the target environment where to provision the VDB. If repository_id unambigously identifies a repository, this is unnecessary and ignored. Otherwise, a compatible repository is randomly selected on the environment.. [optional]  # noqa: E501
            environment_user_id (str): The environment user ID to use to connect to the target environment.. [optional]  # noqa: E501
            repository_id (str): The ID of the target repository where to provision the VDB. A repository typically corresponds to a database installation (Oracle home, database instance, ...). Setting this attribute implicitly determines the environment where to provision the VDB.. [optional]  # noqa: E501
            auto_select_repository (bool): Option to automatically select a compatible environment and repository. Mutually exclusive with repository_id.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this virtual source when target host reboot is detected.. [optional]  # noqa: E501
            template_id (str): The ID of the target VDB Template (Oracle Only).. [optional]  # noqa: E501
            auxiliary_template_id (str): The ID of the configuration template to apply to the auxiliary container database. This is only relevant when provisioning a Multitenant pluggable database into an existing CDB, i.e when the cdb_id property is set.(Oracle Only). [optional]  # noqa: E501
            file_mapping_rules (str): Target VDB file mapping rules (Oracle Only). Rules must be line separated (\\n or \\r) and each line must have the format \"pattern:replacement\". Lines are applied in order.. [optional]  # noqa: E501
            oracle_instance_name (str): Target VDB SID name (Oracle Only).. [optional]  # noqa: E501
            unique_name (str): Target VDB db_unique_name (Oracle Only).. [optional]  # noqa: E501
            vcdb_name (str): When provisioning an Oracle Multitenant vCDB (when the cdb_id property is not set), the name of the provisioned vCDB (Oracle Multitenant Only).. [optional]  # noqa: E501
            vcdb_database_name (str): When provisioning an Oracle Multitenant vCDB (when the cdb_id property is not set), the database name of the provisioned vCDB. Defaults to the value of the vcdb_name property. (Oracle Multitenant Only).. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            open_reset_logs (bool): Whether to open the database after provision (Oracle Only).. [optional]  # noqa: E501
            snapshot_policy_id (str): The ID of the snapshot policy for the VDB.. [optional]  # noqa: E501
            retention_policy_id (str): The ID of the retention policy for the VDB.. [optional]  # noqa: E501
            recovery_model (str): Recovery model of the source database (MSSql Only).. [optional]  # noqa: E501
            pre_script (str): PowerShell script or executable to run prior to provisioning (MSSql Only).. [optional]  # noqa: E501
            post_script (str): PowerShell script or executable to run after provisioning (MSSql Only).. [optional]  # noqa: E501
            cdc_on_provision (bool): Option to enable change data capture (CDC) on both the provisioned VDB and subsequent snapshot-related operations (e.g. refresh, rewind) (MSSql Only).. [optional]  # noqa: E501
            online_log_size (int): Online log size in MB (Oracle Only).. [optional]  # noqa: E501
            online_log_groups (int): Number of online log groups (Oracle Only).. [optional]  # noqa: E501
            archive_log (bool): Option to create a VDB in archivelog mode (Oracle Only).. [optional]  # noqa: E501
            new_dbid (bool): Option to generate a new DB ID for the created VDB (Oracle Only).. [optional]  # noqa: E501
            listener_ids ([str]): The listener IDs for this provision operation (Oracle Only).. [optional]  # noqa: E501
            custom_env_vars ({str: (str,)}): Environment variable to be set when the engine creates a VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution.. [optional]  # noqa: E501
            custom_env_files ([str]): Environment files to be sourced when the Engine creates a VDB. This path can be followed by parameters. Paths and parameters are separated by spaces.. [optional]  # noqa: E501
            oracle_rac_custom_env_files ([OracleRacCustomEnvFile]): Environment files to be sourced when the Engine creates an Oracle RAC VDB. This path can be followed by parameters. Paths and parameters are separated by spaces.. [optional]  # noqa: E501
            oracle_rac_custom_env_vars ([OracleRacCustomEnvVar]): Environment variable to be set when the engine creates an Oracle RAC VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files. (Oracle Multitenant Only). [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_exported_key_file_secret (str): Secret to be used while exporting and importing vPDB encryption keys if Transparent Data Encryption is enabled on the vPDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            cdb_tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with the CDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            vcdb_tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The list of parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            privileged_os_user (str): This privileged unix username will be used to create the VDB. Leave this field blank if you do not want to use privilege elevation. The unix privileged username should begin with a letter or an underscore, followed by letters, digits, underscores, or dashes. They can end with a dollar sign (postgres only).. [optional]  # noqa: E501
            postgres_port (int): Port number for Postgres target database (postgres only).. [optional]  # noqa: E501
            config_settings_stg ([ConfigSettingsStg]): Custom Database-Level config settings (postgres only).. [optional]  # noqa: E501
            tags ([Tag]): The tags to be created for VDB.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)

        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
        '_composed_instances',
        '_var_name_to_model_instances',
        '_additional_properties_model_instances',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """BaseProvisionVDBParameters - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            pre_refresh ([Hook]): The commands to execute on the target environment before refreshing the VDB.. [optional]  # noqa: E501
            post_refresh ([Hook]): The commands to execute on the target environment after refreshing the VDB.. [optional]  # noqa: E501
            pre_self_refresh ([Hook]): The commands to execute on the target environment before refreshing the VDB with data from itself.. [optional]  # noqa: E501
            post_self_refresh ([Hook]): The commands to execute on the target environment after refreshing the VDB with data from itself.. [optional]  # noqa: E501
            pre_rollback ([Hook]): The commands to execute on the target environment before rewinding the VDB.. [optional]  # noqa: E501
            post_rollback ([Hook]): The commands to execute on the target environment after rewinding the VDB.. [optional]  # noqa: E501
            configure_clone ([Hook]): The commands to execute on the target environment when the VDB is created or refreshed.. [optional]  # noqa: E501
            pre_snapshot ([Hook]): The commands to execute on the target environment before snapshotting a virtual source. These commands can quiesce any data prior to snapshotting.. [optional]  # noqa: E501
            post_snapshot ([Hook]): The commands to execute on the target environment after snapshotting a virtual source.. [optional]  # noqa: E501
            pre_start ([Hook]): The commands to execute on the target environment before starting a virtual source.. [optional]  # noqa: E501
            post_start ([Hook]): The commands to execute on the target environment after starting a virtual source.. [optional]  # noqa: E501
            pre_stop ([Hook]): The commands to execute on the target environment before stopping a virtual source.. [optional]  # noqa: E501
            post_stop ([Hook]): The commands to execute on the target environment after stopping a virtual source.. [optional]  # noqa: E501
            target_group_id (str): The ID of the group into which the VDB will be provisioned. If unset, a group is selected randomly on the Engine.. [optional]  # noqa: E501
            name (str): The unique name of the provisioned VDB within a group. If unset, a name is randomly generated.. [optional]  # noqa: E501
            database_name (str): The name of the database on the target environment. Defaults to the value of the name property.. [optional]  # noqa: E501
            cdb_id (str): The ID of the container database (CDB) to provision an Oracle Multitenant database into. This corresponds to a CDB or VCDB API object. When this is not set, a new vCDB will be provisioned.. [optional]  # noqa: E501
            cluster_node_ids ([str]): The cluster node ids, name or addresses for this provision operation (Oracle RAC Only).. [optional]  # noqa: E501
            truncate_log_on_checkpoint (bool): Whether to truncate log on checkpoint (ASE only).. [optional]  # noqa: E501
            os_username (str): The name of the privileged user to run the provision operation (Oracle Only).. [optional]  # noqa: E501
            os_password (str): The password of the privileged user to run the provision operation (Oracle Only).. [optional]  # noqa: E501
            environment_id (str): The ID of the target environment where to provision the VDB. If repository_id unambigously identifies a repository, this is unnecessary and ignored. Otherwise, a compatible repository is randomly selected on the environment.. [optional]  # noqa: E501
            environment_user_id (str): The environment user ID to use to connect to the target environment.. [optional]  # noqa: E501
            repository_id (str): The ID of the target repository where to provision the VDB. A repository typically corresponds to a database installation (Oracle home, database instance, ...). Setting this attribute implicitly determines the environment where to provision the VDB.. [optional]  # noqa: E501
            auto_select_repository (bool): Option to automatically select a compatible environment and repository. Mutually exclusive with repository_id.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this virtual source when target host reboot is detected.. [optional]  # noqa: E501
            template_id (str): The ID of the target VDB Template (Oracle Only).. [optional]  # noqa: E501
            auxiliary_template_id (str): The ID of the configuration template to apply to the auxiliary container database. This is only relevant when provisioning a Multitenant pluggable database into an existing CDB, i.e when the cdb_id property is set.(Oracle Only). [optional]  # noqa: E501
            file_mapping_rules (str): Target VDB file mapping rules (Oracle Only). Rules must be line separated (\\n or \\r) and each line must have the format \"pattern:replacement\". Lines are applied in order.. [optional]  # noqa: E501
            oracle_instance_name (str): Target VDB SID name (Oracle Only).. [optional]  # noqa: E501
            unique_name (str): Target VDB db_unique_name (Oracle Only).. [optional]  # noqa: E501
            vcdb_name (str): When provisioning an Oracle Multitenant vCDB (when the cdb_id property is not set), the name of the provisioned vCDB (Oracle Multitenant Only).. [optional]  # noqa: E501
            vcdb_database_name (str): When provisioning an Oracle Multitenant vCDB (when the cdb_id property is not set), the database name of the provisioned vCDB. Defaults to the value of the vcdb_name property. (Oracle Multitenant Only).. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            open_reset_logs (bool): Whether to open the database after provision (Oracle Only).. [optional]  # noqa: E501
            snapshot_policy_id (str): The ID of the snapshot policy for the VDB.. [optional]  # noqa: E501
            retention_policy_id (str): The ID of the retention policy for the VDB.. [optional]  # noqa: E501
            recovery_model (str): Recovery model of the source database (MSSql Only).. [optional]  # noqa: E501
            pre_script (str): PowerShell script or executable to run prior to provisioning (MSSql Only).. [optional]  # noqa: E501
            post_script (str): PowerShell script or executable to run after provisioning (MSSql Only).. [optional]  # noqa: E501
            cdc_on_provision (bool): Option to enable change data capture (CDC) on both the provisioned VDB and subsequent snapshot-related operations (e.g. refresh, rewind) (MSSql Only).. [optional]  # noqa: E501
            online_log_size (int): Online log size in MB (Oracle Only).. [optional]  # noqa: E501
            online_log_groups (int): Number of online log groups (Oracle Only).. [optional]  # noqa: E501
            archive_log (bool): Option to create a VDB in archivelog mode (Oracle Only).. [optional]  # noqa: E501
            new_dbid (bool): Option to generate a new DB ID for the created VDB (Oracle Only).. [optional]  # noqa: E501
            listener_ids ([str]): The listener IDs for this provision operation (Oracle Only).. [optional]  # noqa: E501
            custom_env_vars ({str: (str,)}): Environment variable to be set when the engine creates a VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution.. [optional]  # noqa: E501
            custom_env_files ([str]): Environment files to be sourced when the Engine creates a VDB. This path can be followed by parameters. Paths and parameters are separated by spaces.. [optional]  # noqa: E501
            oracle_rac_custom_env_files ([OracleRacCustomEnvFile]): Environment files to be sourced when the Engine creates an Oracle RAC VDB. This path can be followed by parameters. Paths and parameters are separated by spaces.. [optional]  # noqa: E501
            oracle_rac_custom_env_vars ([OracleRacCustomEnvVar]): Environment variable to be set when the engine creates an Oracle RAC VDB. See the Engine documentation for the list of allowed/denied environment variables and rules about substitution.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host. Required to provision from snapshots containing encrypted database files. (Oracle Multitenant Only). [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_exported_key_file_secret (str): Secret to be used while exporting and importing vPDB encryption keys if Transparent Data Encryption is enabled on the vPDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            target_vcdb_tde_keystore_path (str): Path to the keystore of the target vCDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            cdb_tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with the CDB. (Oracle Multitenant Only). [optional]  # noqa: E501
            vcdb_tde_key_identifier (str): ID of the key created by Delphix. (Oracle Multitenant Only). [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The list of parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            privileged_os_user (str): This privileged unix username will be used to create the VDB. Leave this field blank if you do not want to use privilege elevation. The unix privileged username should begin with a letter or an underscore, followed by letters, digits, underscores, or dashes. They can end with a dollar sign (postgres only).. [optional]  # noqa: E501
            postgres_port (int): Port number for Postgres target database (postgres only).. [optional]  # noqa: E501
            config_settings_stg ([ConfigSettingsStg]): Custom Database-Level config settings (postgres only).. [optional]  # noqa: E501
            tags ([Tag]): The tags to be created for VDB.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error beause the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
          'anyOf': [
          ],
          'allOf': [
              BaseProvisionVDBParametersAllOf,
              VirtualDatasetHooks,
          ],
          'oneOf': [
          ],
        }



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.3.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_d_source_link_source_parameters import BaseDSourceLinkSourceParameters
from delphix.api.gateway.model.oracle_d_source_link_source_parameters_all_of import OracleDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.source_operation import SourceOperation
from delphix.api.gateway.model.tag import Tag
globals()['BaseDSourceLinkSourceParameters'] = BaseDSourceLinkSourceParameters
globals()['OracleDSourceLinkSourceParametersAllOf'] = OracleDSourceLinkSourceParametersAllOf
globals()['SourceOperation'] = SourceOperation
globals()['Tag'] = Tag
from delphix.api.gateway.model.oracle_d_source_link_source_parameters import OracleDSourceLinkSourceParameters


class TestOracleDSourceLinkSourceParameters(unittest.TestCase):
    """OracleDSourceLinkSourceParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOracleDSourceLinkSourceParameters(self):
        """Test OracleDSourceLinkSourceParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OracleDSourceLinkSourceParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
